{% with instance_css_classes=instance.css_classes instance_inline_styles=instance.inline_styles %}{% spaceless %}
<form name="{{ extra_annotation_form.form_name }}" novalidate>
	<div class="djng-line-spreader">
		{{ extra_annotation_form.non_field_errors }}
	</div>
	<div class="form-group has-feedback">
	{% if headline_legend %}
		{{ extra_annotation_form.annotation.label_tag }}
	{% endif %}
		<textarea class="form-control" id="{{ extra_annotation_form.annotation.id_for_label }}" name="{{ extra_annotation_form.annotation.html_name }}" ng-model="data.extra_annotation.annotation"{% if instance_css_classes %} class="{{ instance_css_classes }}"{% endif %}{% if instance_inline_styles %} style="{{ instance_inline_styles }}"{% endif %}>{{ extra_annotation_form.annotation.value }}</textarea>
		{{ extra_annotation_form.annotation.errors }}
		{% for hidden in extra_annotation_form.hidden_fields %}{{ hidden }}{% endfor %}
	</div>
</form>
{% endspaceless %}{% endwith %}
