[ng-cloak], .ng-cloak {
	display: none !important;
}

.animate-show {
	opacity: 1;
	&.ng-hide-add.ng-hide-add-active, &.ng-hide-remove.ng-hide-remove-active {
		-webkit-transition: all linear 0.2s;
		transition: all linear 0.2s;
	}
	&.ng-hide {
		opacity: 0;
		-webkit-transition: all linear 0.2s;
		transition: all linear 0.2s;
	}
}

form {
	.ng-invalid-bound.ng-pristine, .ng-invalid.ng-dirty {
		border-color: #e9322d;
	}
	.ng-invalid-bound.ng-pristine:focus, .ng-invalid.ng-dirty:focus {
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #ce8483;
	}
}

shop-auth-form {
	.ng-invalid.ng-touched {
		border-color: #e9322d;
	}
}

.shop-form-error {
	position: absolute;
	list-style: none;
	top: 0;
	right: 5px;
	li {
		color: #e9322d;
		font-weight: bold;
		white-space: nowrap;
		padding-left: 8px;
		padding-right: 4px;
		border: 1px dotted #e9322d;
		border-radius: 3px;
		background: #f2dede;
		opacity: 0.85;
		&::before {
			content: "\2716";
			margin-right: 10px;
		}
	}
}

ul.djng-form-errors, ul.djng-field-errors {
	list-style-type: none;
	padding: 0;
	margin: 0;
	top: -8px; right: 0;
	max-width: 100%;
	overflow-x: overlay;
	line-height: 28px;
	z-index: 9;
	li {
		color: #e9322d;
		font-weight: bold;
		white-space: nowrap;
		overflow-x: hidden;
		padding-left: 8px;
		padding-right: 4px;
		&.invalid {
			border: 1px dotted #e9322d;
			border-radius: 3px;
			background: #f2dede;
			opacity: 0.85;
			&:before {
				content: "\2716";
				margin-right: 10px;
			}
		}
	}
}

label.djng-field-required::after {
	content: "\00a0*";
}

ul.djng-field-errors {
	position: absolute;
	li.invalid:before {
		content: "\2716";
		margin-right: 10px;
	}
	li.valid:before {
		color: #00c900;
		content: "\2714";
	}
}
