{% extends "shop/auth/anonymous-base.html" %}
{% load i18n %}

{% block form_title %}
{% blocktrans %}New password for '{{ user_name }}'{% endblocktrans %}
{% endblock %}

{% block form_content %}
	{{ block.super }}
	<div ng-hide="success_message">
		<p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>
		<label class="control-label">{% trans "New Password" %}</label>
		<div style="margin-bottom: 10px" class="input-group">
			<span class="input-group-addon"><i class="fa fa-key fa-fw"></i></span>
			<input type="password" class="form-control" name="new_password1" ng-model="form_data.new_password1" placeholder="{% trans 'New password' %}" />
		</div>
	
		<label class="control-label">{% trans "Confirm Password" %}</label>
		<div style="margin-bottom: 20px" class="input-group">
			<span class="input-group-addon"><i class="fa fa-key fa-fw"></i></span>
			<input type="password" class="form-control" name="new_password2" ng-model="form_data.new_password2" placeholder="{% trans 'Confirm password' %}" />
		</div>
	
		<div class="input-group">
			<button type="button" ng-click="submitForm('{{ request.path }}', 5000)" class="btn btn-primary">{% trans 'Change my password' %}</button>
		</div>
	</div>
{% endblock %}
