{% load i18n %}
<div class="shop-list-item col-xs-6 col-sm-4 col-md-3 col-lg-2"{% if ng %} ng-repeat="product in catalog.products"{% endif %}>
	{% include "shop/catalog/product-figure.html" %}
</div>
