@import "django-angular";

form[shop-dialog-form] {
	.has-feedback {
		.form-control {
			padding-right: 12px;
		}
	}
}

button[shop-dialog-proceed] {
	.glyphicon-refresh-animate {
		animation: spin 2s linear infinite;
	}
}

@keyframes spin { 100% { transform:rotate(360deg); } }
