<form name="{{ accept_condition_form.form_name }}" novalidate>
	<div class="djng-line-spreader">
	{{ accept_condition_form.non_field_errors }}
	</div>
	<div class="has-feedback form-group">
	{{ accept_condition_form.accept.errors }}
	{{ accept_condition_form.accept }}{% if accept_condition_form.accept.field.required %}&nbsp;<sup><strong>*</strong></sup>{% endif %}
	{% for hidden in accept_condition_form.hidden_fields %}{{ hidden }}{% endfor %}
	</div>
</form>
