{% extends "shop/checkout/dialog-base.html" %}
{% load i18n %}

{% block dialog_form %}
<form shop-dialog-form name="{{ payment_method_form.form_name }}" novalidate>
	{% if payment_method_form.has_choices %}
	{{ payment_method_form.as_div }}
	{% else %}
	<input name="__force_invalidation__" style="display: none;" required />
	<p class="bg-danger">{% trans "No payment method available" %}</p>
	{% endif %}
</form>
	{% block payment-provider-form %}
		{% if payment_modifiers.stripe_payment %}
		<div ng-show="data.payment_method.payment_modifier==='stripe-payment'" ng-cloak>
			{# reverse dependency can never be reached, if djangoshop-stripe is not installed #}
			{% include "shop/stripe-creditcard-form.html" %}
		</div>
		{% endif %}
	{% endblock %}
{% endblock dialog_form %}
