<div class="form-group">
	{% if headline_legend %}
	<h4>{{ payment_method_form.payment_modifier.label }}</h4>
	{% endif %}
	<pre class="shop-checkout-summary" djng-bind-if="checkout_summary.payment_method_form">{{ payment_method_form.as_text }}</pre>
</div>
