# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-10 11:14
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import shop.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0007_notification_recipient'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='notify',
            field=shop.models.fields.ChoiceEnumField(verbose_name='Whom to notify'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='recipient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Recipient'),
        ),
    ]
