
/* Adopt form layout for default address model
 * Extend templates billing-address-form.html and shipping-address-form.html and change content
 * of block extra-styles to change these values.
 */

.shop-address-zip_code {
	width: 35%;
	display: inline-block;
	padding-right: 10px;

	.djng-form-control-feedback {
		padding-right: 10px;
	}
}

.shop-address-city {
	width: 65%;
	display: inline-block;
	padding-left: 10px;
}
