# -*- coding: utf-8 -*-
"""
The models in directory default have been added as a pure convenience and for demonstration
purpose. Whenever there is a need to use a modified version, copy one of these models into
the projects model directory and adopt it to your needs. Otherwise just import the model
into your own models.py file without using it. The latter is important to materialize the
model.

Each model is declared in its own file. This is to prevent model validation errors on related
fields if a file containing this definition is imported without using the model.
"""
