{% load static sekizai_tags sass_tags %}{% spaceless %}

{% block extra-styles %}
	{% addtoblock "css" %}<link href="{% sass_src 'shop/css/dialog.scss' %}" rel="stylesheet" type="text/css" />{% endaddtoblock %}
{% endblock %}

{% addtoblock "js" %}<script src="{% static 'djng/js/django-angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "djng.forms" %}

{% addtoblock "js" %}<script src="{% static 'shop/js/utils.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'shop/js/dialogs.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "django.shop.dialogs" %}

{% block dialog_form %}{% verbatim %}
<div class="alert alert-danger">Please extend template <code>shop/checkout/dialog-base.html</code> and override <code>{% block dialog_form %}</code></div>
{% endverbatim %}{% endblock %}

{% endspaceless %}
