{% load i18n static sekizai_tags sass_tags %}

{% addtoblock "css" %}<link href="{% sass_src 'shop/css/order.scss' %}" rel="stylesheet" type="text/css" />{% endaddtoblock %}

{% addtoblock "js" %}<script src="{% static 'shop/js/utils.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "django.shop.utils" %}

<table class="table table-condensed">
{% block shop-order-table %}<!-- table content -->{% endblock %}
</table>
