{% load i18n %}
<div class="panel panel-danger">
	<div class="panel-heading">
		<div class="panel-title">{% trans 'Password reset unsuccessful' %}</div>
	</div>
	<div class="panel-body">
		{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}
	</div>
</div>
