{% extends "shop/auth/anonymous-base.html" %}
{% load i18n %}

{% block form_title %}{% trans "Sign In" %}{% endblock %}

{% block form_content %}
	{{ block.super }}
<div class="form-group has-feedback" style="margin-bottom: 10px">
	<label class="control-label">{% trans "Your e-mail address" %}</label>
	<div class="input-group" ng-class="hasError('username')">
		<span class="input-group-addon"><i class="fa fa-envelope-o fa-fw"></i></span>
		<input type="email" class="form-control" name="username" ng-model="form_data.username" value="" ng-required="true" placeholder="{% trans 'Email' %}" />
	</div>
	<ul ng-messages="login_form.username.$error" class="shop-form-error" ng-cloak>
		<li ng-message="email">{% trans "Please provide a valid email address" %}</li>
	</ul>
</div>

<div class="form-group has-feedback" style="margin-bottom: 20px">
	<label class="control-label">{% trans "Password" %}</label>
	<div class="input-group" ng-class="hasError('password')">
		<span class="input-group-addon"><i class="fa fa-unlock-alt fa-fw"></i></span>
		<input type="password" class="form-control" name="password" ng-model="form_data.password" placeholder="{% trans 'Password' %}" />
	</div>
</div>

	{% block form_footer %}
<div class="form-group">
	<button type="button" ng-click="submitForm('{% url "shop:login" %}')" class="btn btn-primary">{% trans "Login" %}</button>
</div>
	{% endblock form_footer %}
{% endblock %}
