{% load static cascade_tags sekizai_tags sass_tags %}{% spaceless %}

{% addtoblock "css" %}<link href="{% sass_src 'shop/css/dialog.scss' %}" rel="stylesheet" type="text/css" />{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'djng/js/django-angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'shop/js/forms-set.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "django.shop.forms-set" %}

<shop-forms-set>
	{% for child in instance.child_plugin_instances %}{% render_plugin child %}{% endfor %}
</shop-forms-set>

{% endspaceless %}
