{% load i18n static sekizai_tags cms_tags %}{% spaceless %}

{% addtoblock "js" %}<script src="{% static 'shop/js/order.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "django.shop.order" %}

{% if many %}
	<p class="bg-warning">{% blocktrans %}
		Please embed this plugin into a <code>SegmentationPlugin</code> with condition <code>if not many</code>.
	{% endblocktrans %}</p>
{% else %}
	{% page_url "shop-cart" as shop_cart_url %}
	{% with instance_css_classes=instance.css_classes instance_inline_styles=instance.inline_styles %}
	<form shop-order-form="data={reorder: true};" novalidate>
		<button ng-click="update('{{ shop_cart_url }}')"{% if instance_css_classes %} class="{{ instance_css_classes }}"{% endif %}{% if instance_inline_styles %} style="{{ instance_inline_styles }}"{% endif %}>
			{{ instance.glossary.button_content }}
		</button>
	</form>
	{% endwith %}
{% endif %}
{% endspaceless %}
