# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2016-12-27 09:08
from __future__ import unicode_literals

from django import VERSION
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('email_auth', '0002_auto_20160327_1119'),
    ]

    operations = []
    if VERSION >= (1, 10):
        import django.contrib.auth.validators

        operations.append(migrations.AlterField(
            model_name='user',
            name='username',
            field=models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=150, unique=True, validators=[django.contrib.auth.validators.ASCIIUsernameValidator()], verbose_name='username'),
        ))
