<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
		<meta name="viewport" content="width=device-width"/>
	</head>
	<body style="background-color: #eee; font-family: Helvetica,Roboto,Arial,sans-serif;">
		<center>
			<table border="0" cellpadding="0" cellspacing="0" height="100%" width="100%" style="color: #000; background-color: #ddd;">
				<thead>
					<tr>
						<td align="center" valign="top">
							<table border="0" cellpadding="0" cellspacing="0" width="600" style="width: 600px; vertical-align: middle; padding: 15px 25px;">
								<tr>
									<td>
										{% block email-logo %}{% endblock %}
										<h1 style="font-size: 24px; font-weight: bold; margin: 5px; text-align: center;">{% block email-title %}{% endblock %}</h1>
									</td>
								</tr>
								<tr>
									<td style="font-size: 14px; font-weight: normal;">{% block email-thead %}{% endblock %}</td>
								</tr>
							</table>
						</td>
					</tr>
				</thead>

				<tbody>
					<tr>
						<td align="center" valign="top" style="padding: 0;">
							<table border="0" cellpadding="0" cellspacing="0" width="600" style="background-color: #fff; width: 600px;">
								<tr>
									<td>{% block email-tbody %}{% endblock %}</td>
								</tr>
							</table>
						</td>
					</tr>
				</tbody>

				<tfoot>
					<tr>
						<td align="center" valign="top">
							<table border="0" cellpadding="0" cellspacing="0" width="600" style="width: 600px; min-height: 50px; vertical-align: middle; padding: 15px 25px;">
								<tr>
									<td>{% block email-tfoot %}{% endblock %}</td>
								</tr>
							</table>
						</td>
					</tr>
				</tfoot>
			</table>
		</center>
	</body>
</html>