{% extends "cms/wizards/create.html" %}
{% load admin_modify %}

{% block wizard %}
	{{ block.super }}
<script type="text/javascript">
(function($) {
	var field = {
		id: '#id_1-slug',
		dependency_ids: ['#id_1-product_name'],
		dependency_list: ['1-product_name'],
		maxLength: 50,
		allowUnicode: false
	};
	$('.empty-form .form-row .field-slug, .empty-form.form-row .field-slug').addClass('prepopulated_field');
	$(field.id).data('dependency_list', field['dependency_list'])
		.prepopulate(field['dependency_ids'], field.maxLength, field.allowUnicode);
})(django.jQuery);
</script>
{% endblock %}
